@@ -297,6 +297,10 @@ class RIMEStressTestJob:
 
     def get_result_csv(self, filepath: str, version: Optional[str] = None) -> None:
         """Build CSV of test run results."""
+        print(
+            "WARNING: this function is deprecated. "
+            + "Please use `get_test_run_result()` or `get_test_cases_result()` instead."
+        )
         if version and not VersionInfo.isvalid(version):
             raise ValueError(f"Invalid version string: {version}")
         # TODO (QuantumWombat): return different versions of the CSV output based
@@ -858,7 +862,7 @@ class RIMEClient:
             raise ValueError(e)
 
     def create_ct_instance(
-        self, name: str, bin_size_seconds: int, ot_test_run_id: str, project_id: str
+        self, name: str, bin_size_seconds: int, test_run_id: str, project_id: str
     ) -> RIMECTInstance:
         """Create a CT Instance using the CT service.
 
@@ -867,8 +871,8 @@ class RIMEClient:
                 CT instance name.
             bin_size_seconds: int
                 Bin size in seconds. Only supports daily or hourly.
-            ot_test_run_id: str
-                ID of the offline test run that continuous tests will be based on.
+            test_run_id: str
+                ID of the stress test run that continuous tests will be based on.
             project_id: str
                 ID of the project this CT instance belongs to.
 
@@ -885,7 +889,7 @@ class RIMEClient:
             CTInstance(
                 name=name,
                 bin_size_seconds=bin_size_seconds,
-                ot_test_run_id=ot_test_run_id,
+                ot_test_run_id=test_run_id,
                 project_id=project_id,
             )
         )
